@@ -53,6 +53,7 @@ from typing import TYPE_CHECKING, Any
 import github.GithubApp
 import github.GithubObject
 import github.NamedUser
+import github.Organization
 from github import Consts
 from github.GithubObject import Attribute, CompletableGithubObject, NotSet
 from github.PaginatedList import PaginatedList
@@ -60,6 +61,7 @@ from github.PaginatedList import PaginatedList
 if TYPE_CHECKING:
     from github.GithubApp import GithubApp
     from github.NamedUser import NamedUser
+    from github.Organization import Organization
     from github.Reaction import Reaction
 
 
@@ -71,6 +73,7 @@ class IssueComment(CompletableGithubObject):
     https://docs.github.com/en/rest/reference/issues#comments
 
     The OpenAPI schema can be found at
+
     - /components/schemas/issue-comment
 
     """
@@ -89,7 +92,7 @@ class IssueComment(CompletableGithubObject):
         self._reactions: Attribute[dict] = NotSet
         self._updated_at: Attribute[datetime] = NotSet
         self._url: Attribute[str] = NotSet
-        self._user: Attribute[NamedUser] = NotSet
+        self._user: Attribute[NamedUser | Organization] = NotSet
 
     def __repr__(self) -> str:
         return self.get__repr__({"id": self._id.value, "user": self._user.value})
@@ -160,7 +163,7 @@ class IssueComment(CompletableGithubObject):
         return self._url.value
 
     @property
-    def user(self) -> NamedUser:
+    def user(self) -> NamedUser | Organization:
         self._completeIfNotSet(self._user)
         return self._user.value
 
@@ -286,4 +289,10 @@ class IssueComment(CompletableGithubObject):
         if "url" in attributes:  # pragma no branch
             self._url = self._makeStringAttribute(attributes["url"])
         if "user" in attributes:  # pragma no branch
-            self._user = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["user"])
+            self._user = self._makeUnionClassAttributeFromTypeKey(
+                "type",
+                "User",
+                attributes["user"],
+                (github.NamedUser.NamedUser, "User"),
+                (github.Organization.Organization, "Organization"),
+            )
