@@ -21,8 +21,10 @@
 # Copyright 2024 Bernhard M. Wiedemann <githubbmwprimary@lsmod.de>             #
 # Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2024 Jonathan Kliem <jonathan.kliem@gmail.com>                     #
+# Copyright 2025 Christoph Reiter <reiter.christoph@gmail.com>                 #
 # Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2025 Neel Malik <41765022+neel-m@users.noreply.github.com>         #
+# Copyright 2025 Soubhik Kumar Mitra <59209034+x612skm@users.noreply.github.com>#
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -51,7 +53,7 @@ from unittest.mock import Mock
 import jwt
 
 import github
-from github.Auth import Auth
+from github.Auth import Auth, Login
 
 from . import Framework
 from .GithubIntegration import APP_ID, PRIVATE_KEY, PUBLIC_KEY
@@ -64,7 +66,7 @@ class Authentication(Framework.BasicTestCase):
 
     def testBasicAuthentication(self):
         with self.assertWarns(DeprecationWarning) as warning:
-            g = github.Github(self.login.login, self.login.password)
+            g = github.Github("login", "password")
         self.assertEqual(g.get_user("jacquev6").name, "Vincent Jacques")
         self.assertWarning(
             warning,
@@ -101,13 +103,13 @@ class Authentication(Framework.BasicTestCase):
         self.assertEqual(g.get_user("ammarmallik").name, "Ammar Akbar")
         self.assertWarnings(
             warning,
-            "Call to deprecated class AppAuthentication. (Use github.Auth.AppInstallationAuth instead)",
+            "Use github.Auth.AppInstallationAuth instead",
             "Argument app_auth is deprecated, please use auth=github.Auth.AppInstallationAuth(...) instead",
         )
 
     def testLoginAuthentication(self):
         # test data copied from testBasicAuthentication to test parity
-        g = github.Github(auth=self.login)
+        g = github.Github(auth=Login("login", "password"))
         self.assertEqual(g.get_user("jacquev6").name, "Vincent Jacques")
 
     def testTokenAuthentication(self):
@@ -302,8 +304,9 @@ class Authentication(Framework.BasicTestCase):
             key=PUBLIC_KEY,
             algorithms=["RS256"],
             options={"verify_exp": False},
+            issuer=str(APP_ID),
         )
-        self.assertDictEqual(payload, {"iat": 1550055271, "exp": 1550055631, "iss": APP_ID})
+        self.assertDictEqual(payload, {"iat": 1550055271, "exp": 1550055631, "iss": str(APP_ID)})
 
     def testCreateJWTWithExpiration(self):
         auth = github.Auth.AppAuth(APP_ID, PRIVATE_KEY, jwt_expiry=120, jwt_issued_at=-30)
@@ -317,8 +320,9 @@ class Authentication(Framework.BasicTestCase):
             key=PUBLIC_KEY,
             algorithms=["RS256"],
             options={"verify_exp": False},
+            issuer=str(APP_ID),
         )
-        self.assertDictEqual(payload, {"iat": 1550055301, "exp": 1550055391, "iss": APP_ID})
+        self.assertDictEqual(payload, {"iat": 1550055301, "exp": 1550055391, "iss": str(APP_ID)})
 
     def testUserAgent(self):
         g = github.Github(user_agent="PyGithubTester")
