@@ -33,6 +33,11 @@
 # Copyright 2023 Jonathan Leitschuh <jonathan.leitschuh@gmail.com>             #
 # Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
 # Copyright 2023 chantra <chantra@users.noreply.github.com>                    #
+# Copyright 2025 Alex Olieman <alex@olieman.net>                               #
+# Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2025 Maja Massarini <2678400+majamassarini@users.noreply.github.com>#
+# Copyright 2025 Matej Focko <mfocko@users.noreply.github.com>                 #
+# Copyright 2025 Neel Malik <41765022+neel-m@users.noreply.github.com>         #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -52,6 +57,9 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import annotations
+
+import base64
 import contextlib
 import io
 import json
@@ -59,11 +67,11 @@ import os
 import traceback
 import unittest
 import warnings
-from typing import Optional
+from io import BytesIO
 
-import httpretty  # type: ignore
+import responses
 from requests.structures import CaseInsensitiveDict
-from urllib3.util import Url  # type: ignore
+from urllib3.util import Url
 
 import github
 from github import Consts
@@ -106,6 +114,12 @@ class FakeHttpResponse:
     def read(self):
         return self.__output
 
+    def iter_content(self, chunk_size=1):
+        return iter([self.__output[i : i + chunk_size] for i in range(0, len(self.__output), chunk_size)])
+
+    def raise_for_status(self):
+        pass
+
 
 def fixAuthorizationHeader(headers):
     if "Authorization" in headers:
@@ -124,17 +138,29 @@ def fixAuthorizationHeader(headers):
 
 
 class RecordingConnection:
-    def __init__(self, file, protocol, host, port, *args, **kwds):
+    __openFile = None
+
+    @staticmethod
+    def setOpenFile(func):
+        RecordingConnection.__openFile = func
+
+    def __init__(self, protocol, host, port, *args, **kwds):
+        self.__file = self.__openFile("w")
         # write operations make the assumption that the file is not in binary mode
-        assert isinstance(file, io.TextIOBase)
-        self.__file = file
+        assert isinstance(self.__file, io.TextIOBase)
         self.__protocol = protocol
         self.__host = host
         self.__port = port
         self.__cnx = self._realConnection(host, port, *args, **kwds)
+        self.__stream = False
 
-    def request(self, verb, url, input, headers):
+    @property
+    def host(self):
+        return self.__host
+
+    def request(self, verb, url, input, headers, stream=False):
         self.__cnx.request(verb, url, input, headers)
+        self.__stream = stream
         # fixAuthorizationHeader changes the parameter directly to remove Authorization token.
         # however, this is the real dictionary that *will be sent* by "requests",
         # since we are writing here *before* doing the actual request.
@@ -157,16 +183,23 @@ class RecordingConnection:
 
         status = res.status
         headers = res.getheaders()
-        output = res.read()
+        output = res if self.__stream else res.read()
 
         self.__writeLine(status)
         self.__writeLine(list(headers))
-        self.__writeLine(output)
+        if self.__stream:
+            chunks = [chunk for chunk in output.iter_content(chunk_size=64)]
+            output = b"".join(chunks)
+            for chunk in chunks:
+                self.__writeLine(base64.b64encode(chunk).decode("ascii"))
+            self.__writeLine("")
+        else:
+            self.__writeLine(output)
+        self.__writeLine("")
 
         return FakeHttpResponse(status, headers, output)
 
     def close(self):
-        self.__writeLine("")
         return self.__cnx.close()
 
     def __writeLine(self, line):
@@ -176,33 +209,58 @@ class RecordingConnection:
 class RecordingHttpConnection(RecordingConnection):
     _realConnection = github.Requester.HTTPRequestsConnectionClass
 
-    def __init__(self, file, *args, **kwds):
-        super().__init__(file, "http", *args, **kwds)
+    def __init__(self, *args, **kwds):
+        super().__init__("http", *args, **kwds)
 
 
 class RecordingHttpsConnection(RecordingConnection):
     _realConnection = github.Requester.HTTPSRequestsConnectionClass
 
-    def __init__(self, file, *args, **kwds):
-        super().__init__(file, "https", *args, **kwds)
+    def __init__(self, *args, **kwds):
+        super().__init__("https", *args, **kwds)
 
 
 class ReplayingConnection:
-    def __init__(self, file, protocol, host, port, *args, **kwds):
-        self.__file = file
+    __openFile = None
+
+    @staticmethod
+    def setOpenFile(func):
+        ReplayingConnection.__openFile = func
+
+    def __init__(self, protocol, host, port, *args, **kwds):
+        self.__file = self.__openFile("r")
         self.__protocol = protocol
         self.__host = host
         self.__port = port
+        self.__stream = False
         self.response_headers = CaseInsensitiveDict()
 
         self.__cnx = self._realConnection(host, port, *args, **kwds)
 
-    def request(self, verb, url, input, headers):
-        full_url = Url(scheme=self.__protocol, host=self.__host, port=self.__port, path=url)
+    @property
+    def host(self):
+        return self.__host
 
-        httpretty.register_uri(verb, full_url.url, body=self.__request_callback)
+    def request(
+        self,
+        verb,
+        url,
+        input,
+        headers,
+        stream: bool = False,
+    ):
+        port = self.__port if self.__port else 443 if self.__protocol == "https" else 80
+        full_url = Url(scheme=self.__protocol, host=self.__host, port=port, path=url)
 
-        self.__cnx.request(verb, url, input, headers)
+        response_headers = self.response_headers.copy()
+        responses.add_callback(
+            method=verb,
+            url=full_url.url,
+            callback=lambda request: self.__request_callback(verb, full_url.url, response_headers),
+        )
+
+        self.__stream = stream
+        self.__cnx.request(verb, url, input, headers, stream=stream)
 
     def __readNextRequest(self, verb, url, input, headers):
         fixAuthorizationHeader(headers)
@@ -237,7 +295,16 @@ class ReplayingConnection:
 
         status = int(readLine(self.__file))
         self.response_headers = CaseInsensitiveDict(eval(readLine(self.__file)))
-        output = bytearray(readLine(self.__file), "utf-8")
+        if self.__stream:
+            output = BytesIO()
+            while True:
+                line = readLine(self.__file)
+                if not line:
+                    break
+                output.write(base64.b64decode(line))
+            output = output.getvalue()
+        else:
+            output = bytearray(readLine(self.__file), "utf-8")
         readLine(self.__file)
 
         # make a copy of the headers and remove the ones that interfere with the response handling
@@ -247,10 +314,10 @@ class ReplayingConnection:
         adding_headers.pop("content-encoding", None)
 
         response_headers.update(adding_headers)
+
         return [status, response_headers, output]
 
     def getresponse(self):
-        # call original connection, this will go all the way down to the python socket and will be intercepted by httpretty
         response = self.__cnx.getresponse()
 
         # restore original headers to the response
@@ -265,46 +332,45 @@ class ReplayingConnection:
 class ReplayingHttpConnection(ReplayingConnection):
     _realConnection = github.Requester.HTTPRequestsConnectionClass
 
-    def __init__(self, file, *args, **kwds):
-        super().__init__(file, "http", *args, **kwds)
+    def __init__(self, *args, **kwds):
+        super().__init__("http", *args, **kwds)
 
 
 class ReplayingHttpsConnection(ReplayingConnection):
     _realConnection = github.Requester.HTTPSRequestsConnectionClass
 
-    def __init__(self, file, *args, **kwds):
-        super().__init__(file, "https", *args, **kwds)
+    def __init__(self, *args, **kwds):
+        super().__init__("https", *args, **kwds)
 
 
 class BasicTestCase(unittest.TestCase):
     recordMode = False
-    tokenAuthMode = False
-    jwtAuthMode = False
-    per_page = Consts.DEFAULT_PER_PAGE
-    retry = None
-    pool_size = None
-    seconds_between_requests: Optional[float] = None
-    seconds_between_writes: Optional[float] = None
     replayDataFolder = os.path.join(os.path.dirname(__file__), "ReplayData")
 
+    def __init__(self, methodName="runTest") -> None:
+        super().__init__(methodName)
+        self.authMode = "token"
+        self.per_page = Consts.DEFAULT_PER_PAGE
+        self.retry = None
+        self.pool_size = None
+        self.seconds_between_requests: float | None = None
+        self.seconds_between_writes: float | None = None
+
     def setUp(self):
         super().setUp()
+        self.__customFilename: str | None = None
         self.__fileName = ""
         self.__file = None
         if (
             self.recordMode
         ):  # pragma no cover (Branch useful only when recording new tests, not used during automated tests)
+            RecordingConnection.setOpenFile(self.__openFile)
             github.Requester.Requester.injectConnectionClasses(
-                lambda ignored, *args, **kwds: RecordingHttpConnection(self.__openFile("w"), *args, **kwds),
-                lambda ignored, *args, **kwds: RecordingHttpsConnection(self.__openFile("w"), *args, **kwds),
+                RecordingHttpConnection,
+                RecordingHttpsConnection,
             )
             import GithubCredentials  # type: ignore
 
-            self.login = (
-                github.Auth.Login(GithubCredentials.login, GithubCredentials.password)
-                if GithubCredentials.login and GithubCredentials.password
-                else None
-            )
             self.oauth_token = (
                 github.Auth.Token(GithubCredentials.oauth_token) if GithubCredentials.oauth_token else None
             )
@@ -315,16 +381,31 @@ class BasicTestCase(unittest.TestCase):
                 else None
             )
         else:
+            ReplayingConnection.setOpenFile(self.__openFile)
             github.Requester.Requester.injectConnectionClasses(
-                lambda ignored, *args, **kwds: ReplayingHttpConnection(self.__openFile("r"), *args, **kwds),
-                lambda ignored, *args, **kwds: ReplayingHttpsConnection(self.__openFile("r"), *args, **kwds),
+                ReplayingHttpConnection,
+                ReplayingHttpsConnection,
             )
-            self.login = github.Auth.Login("login", "password")
             self.oauth_token = github.Auth.Token("oauth_token")
             self.jwt = github.Auth.AppAuthToken("jwt")
             self.app_auth = github.Auth.AppAuth(123456, APP_PRIVATE_KEY)
 
-            httpretty.enable(allow_net_connect=False)
+            responses.start()
+
+    def setPerPage(self, per_page):
+        self.per_page = per_page
+
+    def setRetry(self, retry):
+        self.retry = retry
+
+    def setPoolSize(self, pool_size):
+        self.pool_size = pool_size
+
+    def setSecondsBetweenRequests(self, seconds_between_requests):
+        self.seconds_between_requests = seconds_between_requests
+
+    def setSecondsBetweenWrites(self, seconds_between_writes):
+        self.seconds_between_writes = seconds_between_writes
 
     @property
     def thisTestFailed(self) -> bool:
@@ -340,9 +421,8 @@ class BasicTestCase(unittest.TestCase):
 
     def tearDown(self):
         super().tearDown()
-        httpretty.disable()
-        httpretty.reset()
-
+        responses.stop()
+        responses.reset()
         self.__closeReplayFileIfNeeded(silent=self.thisTestFailed)
         github.Requester.Requester.resetConnectionClasses()
 
@@ -360,14 +440,26 @@ class BasicTestCase(unittest.TestCase):
             warnings.filterwarnings("ignore", category=category, module=module)
             yield
 
+    @contextlib.contextmanager
+    def replayData(self, filename: str):
+        previous = self.__customFilename
+        self.__customFilename = filename
+        try:
+            yield
+        finally:
+            self.__customFilename = previous
+
     def __openFile(self, mode):
-        for _, _, functionName, _ in traceback.extract_stack():
-            if functionName.startswith("test") or functionName == "setUp" or functionName == "tearDown":
-                if functionName != "test":  # because in class Hook(Framework.TestCase), method testTest calls Hook.test
-                    fileName = os.path.join(
-                        self.replayDataFolder,
-                        f"{self.__class__.__name__}.{functionName}.txt",
-                    )
+        fileName = None
+        if self.__customFilename:
+            fileName = self.__customFilename
+        else:
+            for _, _, functionName, _ in traceback.extract_stack():
+                if functionName.startswith("test") or functionName == "setUp" or functionName == "tearDown":
+                    # because in class Hook(Framework.TestCase), method testTest calls Hook.test
+                    if functionName != "test":
+                        fileName = f"{self.__class__.__name__}.{functionName}.txt"
+        fileName = os.path.join(self.replayDataFolder, fileName) if fileName else None
         if fileName != self.__fileName:
             self.__closeReplayFileIfNeeded()
             self.__fileName = fileName
@@ -410,53 +502,29 @@ class TestCase(BasicTestCase):
         github.Requester.Requester.setDebugFlag(True)
         github.Requester.Requester.setOnCheckMe(self.getFrameChecker())
 
-        self.g = self.get_github(self.retry, self.pool_size)
+        self.g = self.get_github(self.authMode, self.retry, self.pool_size)
 
-    def get_github(self, retry, pool_size):
-        if self.tokenAuthMode:
-            return github.Github(
-                auth=self.oauth_token,
-                per_page=self.per_page,
-                retry=retry,
-                pool_size=pool_size,
-                seconds_between_requests=self.seconds_between_requests,
-                seconds_between_writes=self.seconds_between_writes,
-            )
-        elif self.jwtAuthMode:
-            return github.Github(
-                auth=self.jwt,
-                per_page=self.per_page,
-                retry=retry,
-                pool_size=pool_size,
-                seconds_between_requests=self.seconds_between_requests,
-                seconds_between_writes=self.seconds_between_writes,
-            )
+    def get_github(self, authMode, retry=None, pool_size=None):
+        if authMode == "token":
+            auth = self.oauth_token
+        elif authMode == "jwt":
+            auth = self.jwt
+        elif authMode == "app":
+            auth = self.app_auth
+        elif self.authMode == "none":
+            auth = None
         else:
-            return github.Github(
-                auth=self.login,
-                per_page=self.per_page,
-                retry=retry,
-                pool_size=pool_size,
-                seconds_between_requests=self.seconds_between_requests,
-                seconds_between_writes=self.seconds_between_writes,
-            )
+            raise ValueError(f"Unsupported test auth mode: {authMode}")
+
+        return github.Github(
+            auth=auth,
+            per_page=self.per_page,
+            retry=retry,
+            pool_size=pool_size,
+            seconds_between_requests=self.seconds_between_requests,
+            seconds_between_writes=self.seconds_between_writes,
+        )
 
 
 def activateRecordMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
     BasicTestCase.recordMode = True
-
-
-def activateTokenAuthMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
-    BasicTestCase.tokenAuthMode = True
-
-
-def activateJWTAuthMode():  # pragma no cover (Function useful only when recording new tests, not used during automated tests)
-    BasicTestCase.jwtAuthMode = True
-
-
-def enableRetry(retry):
-    BasicTestCase.retry = retry
-
-
-def setPoolSize(pool_size):
-    BasicTestCase.pool_size = pool_size
