@@ -47,8 +47,7 @@ class Retry(Framework.TestCase):
         # status codes returned on random github server errors
         status_forcelist = (500, 502, 504)
         retry = urllib3.Retry(total=3, read=3, connect=3, status_forcelist=status_forcelist)
-
-        Framework.enableRetry(retry)
+        self.setRetry(retry)
         super().setUp()
 
     def testShouldNotRetryWhenStatusNotOnList(self):
